/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: StatelessRunAsBean.java 1970 2007-10-16 11:49:25Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.examples.security;

import javax.annotation.Resource;
import javax.annotation.security.DeclareRoles;
import javax.annotation.security.RunAs;
import javax.ejb.EJB;
import javax.ejb.Remote;
import javax.ejb.SessionContext;
import javax.ejb.Stateless;

/**
 * Stateless Bean with secured methods.
 * Two roles are declared : user and admin.
 * @author Florent Benoit
 */
@Stateless
@Remote(StatelessRunAsRemote.class)
@DeclareRoles({"admin"})
@RunAs("admin")
public class StatelessRunAsBean implements StatelessRunAsRemote {

    /**
     * SessionContext used to get current caller.
     */
    @Resource
    private SessionContext sessionContext;

    /**
     * Link to bean.
     */
    @EJB
    private StatelessRemote other;


    /**
     * Prints the current caller.
     */
    public void printCurrentCaller() {
        System.out.println("Caller is '" + sessionContext.getCallerPrincipal());
    }

    /**
     * Call method that is allowed only for admin. (but use run-as role).
     */
    public void callBeanWithRunAsAdmin() {
        other.onlyAdminAllowed();

        // Also call a method that permit two roles
        other.someRolesAllowed();

    }


}
